/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	const magazine_palace_section_lists = ['post_grid_section','banner_post_section','sport_post_section','featured_Slider_section','three_col_slider_section','two_col_section','latest_post_section','main_slider_section','tag_section','breakingnews_section','slider_news_section','two_section_section','multi_post_section','post_carousel_section','have_missed_section','featured_post_section','main_slider_section','featured_category_section','blog_slider_section','instagram_section'];
    magazine_palace_section_lists.forEach( magazine_palace_homepage_scroll_preview );

    function magazine_palace_homepage_scroll_preview(item, index) {
    	// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {
			
			// Initially hide the theme option placeholders on load.
			$( '.panel-placeholder' ).hide();

			wp.customize.preview.bind( item, function( data ) {
				// Only on the front page.
				if ( ! $( 'body' ).hasClass( 'home' ) ) {
					return;
				}

				// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
				if ( true === data.expanded ) {
					$('html, body').animate({
				        'scrollTop' : $('#magazine_palace_'+item).position().top
				    });
				} 
			});

		});
 	}

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'magazine_palace_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'magazine_palace_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'magazine_palace_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
				.removeClass( 'colors-light colors-dark colors-custom' )
				.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'magazine_palace_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			    color = style.data( 'color' ),
			    css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			     .data( 'color', to );
		} );
	} );

	// topbar
	wp.customize( 'magazine_palace_theme_options[topbar_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[topbar_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .main-navigation ul.nav-menu > li > a, #top-navigation time' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[topbar_btn_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .live-button .btn' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[topbar_btn_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .live-button .btn' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[topbar_btn_text]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .live-button .btn' ).text( to );
		} );
	} );

	// end topbar

	// header
	wp.customize( 'magazine_palace_theme_options[header_nav_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one #site-navigation.main-navigation' ).css( 'background-color', to );
			$( '.header-two' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_icon_color]', function( value ) {
		value.bind( function( to ) {
			$( '.main-navigation ul.nav-menu > li.home-icon > a > svg' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '.main-navigation a, .main-navigation ul.nav-menu > li > a, .main-navigation form.search-form ::-webkit-input-placeholder' ).css( 'color', to );
			$( '.main-navigation form.search-form svg.icon-search, .main-navigation .nav-menu > li > a > svg.icon-down, .search-menu svg.icon-search' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_search_bg]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one .main-navigation form.search-form input' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_overlay_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one .header-overlay' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_bg_image]', function( value ) {
		value.bind( function( to ) {		
			$( '.header-one .header-image' ).css( { 'background-image': 'url(' + to + ')', 'background-repeat': 'no-repeat', 'background-size': 'cover', 'background-position': 'center' } );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.header-one .header-image' ).css( 'padding-top', to + 'px' );
			$( '.header-one .header-image' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_search_enable]', function( value ) {
		value.bind( function( to ) {	
			if ( to == 'true' ) {
				$( '.header-one .main-navigation-search, .header-two .search-menu' ).css( 'display', 'block' );
				
			}else{
				$( '.header-one .main-navigation-search, .header-two .search-menu' ).css( 'display', 'none' );
				$( '.header-two .nav-menu' ).css( 'text-align', 'right' );
			}
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[header_home_icon_enable]', function( value ) {
		value.bind( function( to ) {	
			if ( to == 'true' ) {
				$( '.home-icon a' ).css( 'display', 'block' );
			}else{
				$( '.home-icon a' ).css( 'display', 'none' );
			}
		} );
	} );

	// end header

	

	// breakingnews 

	wp.customize( 'magazine_palace_theme_options[breakingnews_label_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_breakingnews_section .news-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[breakingnews_label_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_breakingnews_section .news-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[breakingnews_row_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.breaking-news-post' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[breakingnews_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.breaking-news-post .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[breakingnews_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_breakingnews_section .news-title' ).text( to );
		} );
	} );


	// end breakingnews


	// have missed section
	wp.customize( 'magazine_palace_theme_options[have_missed_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section article .posted-on a, #magazine_palace_have_missed_section article .min-read, #magazine_palace_have_missed_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[have_missed_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_have_missed_section .section-title' ).text( to );
		} );
	} );

	// end have missed section

	// featured post section
	wp.customize( 'magazine_palace_theme_options[featured_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section article .posted-on a, #magazine_palace_featured_post_section article .min-read, #magazine_palace_featured_post_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[featured_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_featured_post_section .section-title' ).text( to );
		} );
	} );

	// end featured post section

	
	// banner post section
	wp.customize( 'magazine_palace_theme_options[banner_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[banner_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_banner_post_section .section-title' ).text( to );
		} );
	} );

	// end banner post section


	// three col section
	wp.customize( 'magazine_palace_theme_options[three_col_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section article .posted-on a, #magazine_palace_three_col_slider_section article .min-read, #magazine_palace_three_col_slider_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[three_col_slider_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_three_col_slider_section .section-title' ).text( to );
		} );
	} );

	// end three col section

	// two col section
	wp.customize( 'magazine_palace_theme_options[two_col_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section article .posted-on a, #magazine_palace_two_col_section article .min-read, #magazine_palace_two_col_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[two_col_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_two_col_section .section-title' ).text( to );
		} );
	} );

	// end two col section

	
	// single post/page 
	wp.customize( 'magazine_palace_theme_options[single_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_theme_options[single_post_related_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #related-post' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_theme_options[single_post_entry_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper .entry-container' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_theme_options[single_post_comment_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #comments' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_theme_options[single_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[single_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[single_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[single_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[single_post_related_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #related-post' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[single_post_comment_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #comments' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[single_post_entry_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper .entry-container.post-content' ).css( 'padding', to + 'px' );
		} );
	} );
	// end single post/page

	// widget 
	wp.customize( 'magazine_palace_theme_options[widget_panel_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages, #right-sidebar' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[widget_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget, #right-sidebar .widget' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[widget_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[widget_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[widget_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[widget_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[widget_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget,  #right-sidebar .widget' ).css( 'padding', to + 'px' );
		} );
	} );

	// end widget

	// homepage
	wp.customize( 'magazine_palace_theme_options[homepage_section_gap]', function( value ) {
		value.bind( function( to ) {		
			$( '.home-section' ).css( 'margin', to + 'px' );
			$( '#main-post-wrapper main div:first-child, #main-post-wrapper main div:last-child' ).css( 'margin-top', '0px' );
			$( '.right-sidebar #primary, .left-sidebar #primary' ).css( 'paddingright', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[homepage_main_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[homepage_main_container_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[homepage_main_container_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[homepage_main_container_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[homepage_main_container_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );



	//end homepage

	// slider news 
	wp.customize( 'magazine_palace_theme_options[slider_news_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper #magazine_palace_slider_news_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_theme_options[slider_news_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );
	wp.customize( 'magazine_palace_theme_options[slider_news_slider_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper #magazine_palace_slider_news_section' ).css( 'padding', to + 'px' );
		} );
	} );
	// end slider news 

	wp.customize( 'magazine_palace_theme_options[footer_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon' ).css( 'background-color', to );
		} );
	} );


} )( jQuery );
