<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 */


if ( ! function_exists( 'magazine_palace_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Magazine Palace 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazine_palace_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'magazine_palace_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'magazine_palace_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Magazine Palace 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazine_palace_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'magazine_palace_theme_options[pagination_enable]' )->value();
	}
endif;


/**
 * Check if topbar section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[topbar_section_enable]' )->value() );
}



/**
 * Check if breakingnews section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_breakingnews_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[breakingnews_section_enable]' )->value() );
}

/**
 * Check if breaking news slider section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_breakingnews_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[slider_section_enable]' )->value() );
}



/**
 * Check if Featured Slider section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_slider_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[slider_news_section_enable]' )->value() );
}


/**
 * Check if have missed section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_have_missed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[have_missed_section_enable]' )->value() );
}


/**
 * Check if featured_post section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[featured_post_section_enable]' )->value() );
}



/**
 * Check if Banner Post section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_banner_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[banner_post_section_enable]' )->value() );
}



/**
 * Check if two col section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_two_col_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[two_col_section_enable]' )->value() );
}


/**
 * Check if Three col slider section is enabled.
 *
 * @since Magazine Palace 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_is_three_col_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_theme_options[three_col_slider_section_enable]' )->value() );
}

