<?php
/**
 * Magazine Palace Customizer.
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 */

//load upgrade-to-pro section
require get_template_directory() . '/inc/customizer/upgrade-to-pro/class-customize.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function magazine_palace_customize_register( $wp_customize ) {
	$options = magazine_palace_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'magazine_palace_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'magazine_palace_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'magazine-palace' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'magazine_palace_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'magazine_palace_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'magazine-palace' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'magazine_palace_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'magazine_palace_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'magazine_palace_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'magazine-palace' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'magazine-palace' ),
			'show-all'     => esc_html__( 'Show All', 'magazine-palace' ),
			'title-only'   => esc_html__( 'Title Only', 'magazine-palace' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'magazine-palace' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'magazine-palace' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'magazine-palace' ),
			)
	) );


	// Add panel for common theme options
	$wp_customize->add_panel( 'magazine_palace_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','magazine-palace' ),
	    'description'=> esc_html__( 'Magazine Palace Theme Options.', 'magazine-palace' ),
	    'priority'   => 150,
	) );

	// topbar
	require get_template_directory() . '/inc/customizer/theme-options/topbar.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/topbar.php';

	// header
	require get_template_directory() . '/inc/customizer/theme-options/header.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/header.php';

	// page banner
	require get_template_directory() . '/inc/customizer/theme-options/page-banner.php';


	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';
	
	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/single-post.php';

	require get_template_directory() . '/inc/customizer/theme-options/style/widget.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'magazine_palace_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','magazine-palace' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'magazine-palace' ),
	    'priority'   => 140,
	) );

	require get_template_directory() . '/inc/customizer/sections/home-layout.php';


	// load breakingnews option
	require get_template_directory() . '/inc/customizer/sections/breakingnews.php';	
	require get_template_directory() . '/inc/customizer/sections/style/breakingnews.php';	

	// load slider news option
	require get_template_directory() . '/inc/customizer/sections/slider-news.php';	
	require get_template_directory() . '/inc/customizer/sections/style/slider-news.php';

	// load magazine_palace_post_carousel_section option
	require get_template_directory() . '/inc/customizer/sections/have-missed.php';
	require get_template_directory() . '/inc/customizer/sections/style/have-missed.php';

	// load featured post option
	require get_template_directory() . '/inc/customizer/sections/featured-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/featured-post.php';

	// load banner post option
	require get_template_directory() . '/inc/customizer/sections/banner-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/banner-post.php';

	// load three col slider option
	require get_template_directory() . '/inc/customizer/sections/three-col-slider.php';
	require get_template_directory() . '/inc/customizer/sections/style/three-col-slider.php';

	// load two col option
	require get_template_directory() . '/inc/customizer/sections/two-col.php';
	require get_template_directory() . '/inc/customizer/sections/style/two-col.php';

	
	
}
add_action( 'customize_register', 'magazine_palace_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function magazine_palace_customize_preview_js() {
	wp_enqueue_script( 'magazine-palace-customizer', get_template_directory_uri() . '/assets/js/customizer' . magazine_palace_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'magazine_palace_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function magazine_palace_customize_control_js() {
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . magazine_palace_min() . '.css' );
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . magazine_palace_min() . '.js', array( 'jquery' ), '1.4.2', true );

	wp_enqueue_style( 'magazine-palace-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . magazine_palace_min() . '.css' );
	wp_enqueue_script( 'magazine-palace-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . magazine_palace_min() . '.js', array(), '1.0', true );
	$magazine_palace_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'magazine-palace' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'magazine-palace-customize-controls', 'magazine_palace_reset_data', $magazine_palace_reset_data );

	$theme_path_url = array( 'url' => get_theme_file_uri() );

	wp_localize_script( 'magazine-palace-customize-controls', 'theme_url', $theme_path_url );
}
add_action( 'customize_controls_enqueue_scripts', 'magazine_palace_customize_control_js' );

if ( !function_exists( 'magazine_palace_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function magazine_palace_reset_options() {
		$options = magazine_palace_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'magazine_palace_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'magazine_palace_reset_options' );
