<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 * @return array An array of default values
 */

function magazine_palace_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$magazine_palace_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#e5383e',
		'colorscheme'					=> 'default',
		'header_overlay_color'			=> '#000',
		'header_overlay'				=> 5,
		'home_layout'					=> 'default-design',
		'homepage_section_gap'			=> 10,
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		'bg_image'						=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'widget_enable_sticky_homepage' => false,
		'transparent_menu' 				=> false,
		'widget_enable_sticky' 			=> false,


		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'magazine-palace' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'magazine-palace' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,
		'footer_wrapper_enable'			=> false,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'homepage_sortable' 						=> 'breakingnews,slider_news,have_missed,featured_post,main_content',
		'homepage_inner_sortable'					=> 'banner_post,three_col_slider,two_col',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'magazine-palace' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,
		'single_post_hide_post_title'   => false,
		'single_post_hide_featured_image'   => false,

		'page_banner_wrapper_enable'	=> false,
		'page_banner_breadcrumb_enable'	=> false,
		'page_banner_header_image_enable'	=> false,

		/* Front Page */

		// Tag
		'tag_section_enable'			=> false,
		'tag_title'						=> esc_html__('Popular Tags', 'magazine-palace' ),


		// Topbar
		'topbar_section_enable'			=> false,
		'topbar_btn_text'				=> esc_html__('Live', 'magazine-palace' ),
		'topbar_date_icon_enable'		=> false,
		'topbar_design'					=> 'topbar-one',
		'topbar_section_wrapper_enable'	=> false,

		// Header
		'header_design'		=> 'header-one',
		'header_home_icon_enable' => true,
		'header_search_enable'	=> true,
		'header_wrapper_enable'	=> false,

		// Breaking News
		'breakingnews_section_enable'			=> false,
		'breakingnews_featured_image_enable'	=> false,
		'breakingnews_title'					=> esc_html__( 'Breaking News', 'magazine-palace' ),
		'breaking_news_icon'					=> 'speaker',

		// have_missed
		'have_missed_section_enable'		=> false,
		'have_missed_autoplay_enable'		=> false,
		'have_missed_title'				=> esc_html__( 'Have Missed', 'magazine-palace' ),

		// featured_post
		'featured_post_section_enable'		=> false,
		'featured_post_autoplay_enable'		=> false,
		'featured_post_title'				=> esc_html__( 'Featured Post', 'magazine-palace' ),


		// banner_post
		'banner_post_section_enable'		=> false,
		'banner_post_title'					=> esc_html__( 'Banner Post', 'magazine-palace' ),


		// slider_news
		'slider_news_section_enable'		=> false,
		'slider_news_autoplay_enable'		=> false,
		'slider_news_title'				=> esc_html__( 'Slider News', 'magazine-palace' ),

		// three_col_slider
		'three_col_slider_section_enable'		=> false,
		'three_col_slider_autoplay_enable'		=> false,
		'three_col_slider_title'				=> esc_html__( 'Three Column', 'magazine-palace' ),

		// two_col
		'two_col_section_enable'		=> false,
		'two_col_title'				=> esc_html__( 'Two Column', 'magazine-palace' ),

		'main_content_section_enable'			=> false,


	);

	$output = apply_filters( 'magazine_palace_default_theme_options', $magazine_palace_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}