<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 */

$options = magazine_palace_get_theme_options();


if ( ! function_exists( 'magazine_palace_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Magazine Palace 1.0.0
	 */
	function magazine_palace_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'magazine_palace_doctype', 'magazine_palace_doctype', 10 );


if ( ! function_exists( 'magazine_palace_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'magazine_palace_before_wp_head', 'magazine_palace_head', 10 );

if ( ! function_exists( 'magazine_palace_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'magazine-palace' ); ?></a>
			<div class="menu-overlay"></div>

		<?php
	}
endif;
add_action( 'magazine_palace_page_start_action', 'magazine_palace_page_start', 10 );

if ( ! function_exists( 'magazine_palace_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'magazine_palace_page_end_action', 'magazine_palace_page_end', 10 );

if ( ! function_exists( 'magazine_palace_topbar' ) ) :
	/**
	 * Topbar html codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */

	function magazine_palace_topbar() { 
		$options = magazine_palace_get_theme_options(); 

		if ( ! $options['topbar_section_enable'] )
				return;
		?>
		<div class="menu-overlay"></div>
	<?php
		get_template_part( 'template-parts/topbar/topbar-one' );
	}



endif;
add_action( 'magazine_palace_header_action', 'magazine_palace_topbar', 10 );

if ( ! function_exists( 'magazine_palace_header' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_header() {
		$options = magazine_palace_get_theme_options();  
		get_template_part( 'template-parts/header/header-one' );
	}
endif;
add_action( 'magazine_palace_header_action', 'magazine_palace_header', 20 );


if ( ! function_exists( 'magazine_palace_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'magazine_palace_content_start_action', 'magazine_palace_content_start', 10 );
if ( ! function_exists( 'magazine_palace_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  magazine_palace Pro 1.0.0
     *
     */
    function magazine_palace_header_image() {
        if ( magazine_palace_is_frontpage() )
            return;
        $options = magazine_palace_get_theme_options();  
        $header_image = get_header_image();
        if ( !$options['page_banner_header_image_enable'] ) {
        	if ( is_singular() ) :
	            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
	        endif;
        }
        
        $page_banner_wrapper_class = $options['page_banner_wrapper_enable'] ? 'wrapper' : '';
        ?>

        <div id="page-site-header" class="relative <?php echo $page_banner_wrapper_class ?>" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php magazine_palace_custom_header_banner_title(); ?>
                </header>
                <?php if ( $options['page_banner_breadcrumb_enable'] ): ?>
                	<?php magazine_palace_add_breadcrumb(); ?>
                <?php endif ?>
                
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'magazine_palace_header_image_action', 'magazine_palace_header_image', 20 );

if ( ! function_exists( 'magazine_palace_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  magazine_palace Pro 1.0.0
	 */
	function magazine_palace_add_breadcrumb() {
		$options = magazine_palace_get_theme_options();

		
		// Bail if Home Page.
		if ( magazine_palace_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * magazine_palace_simple_breadcrumb hook
				 *
				 * @hooked magazine_palace_simple_breadcrumb -  10
				 *
				 */
				do_action( 'magazine_palace_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;
if ( ! function_exists( 'magazine_palace_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_content_end() {
		?>
			
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'magazine_palace_content_end_action', 'magazine_palace_content_end', 10 );

if ( ! function_exists( 'magazine_palace_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_footer_start() {
		$options = magazine_palace_get_theme_options();
		$footer_wrapper_class = $options['footer_wrapper_enable'] ? 'wrapper' : '';
		?>
		<footer id="colophon" class="site-footer <?php echo $footer_wrapper_class ?>" role="contentinfo">
		<?php
	}
endif;
add_action( 'magazine_palace_footer', 'magazine_palace_footer_start', 10 );

if ( ! function_exists( 'magazine_palace_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_footer_site_info() {
		$options = magazine_palace_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );
		$theme_data = wp_get_theme();
        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info">
            <div class="wrapper">
                <span>
                	<?php 
                	echo magazine_palace_santize_allow_tag( $copyright_text ); 
                	if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( ' | ' );
					}
                	?>
                	
					<?php echo esc_html__( ' All Rights Reserved | ', 'magazine-palace' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'magazine-palace' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ?>
            	</span>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'magazine_palace_footer', 'magazine_palace_footer_site_info', 40 );



if ( ! function_exists( 'magazine_palace_footer_end' ) ) :
	/**
	
	 * Footer starts
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_footer_end() {
		?>
		</footer>
		<?php
		$options  = magazine_palace_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo magazine_palace_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php
		endif;
	}
endif;
add_action( 'magazine_palace_footer', 'magazine_palace_footer_end', 100 );

if ( ! function_exists( 'magazine_palace_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_loader() {
		$options = magazine_palace_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo magazine_palace_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'magazine_palace_before_header', 'magazine_palace_loader', 10 );

if ( ! function_exists( 'magazine_palace_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Magazine Palace 1.0.0
	 *
	 */
	function magazine_palace_infinite_loader_spinner() { 
		$id = get_the_ID();
		$options = magazine_palace_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( ! empty($id) ) {
				echo '<div class="blog-loader">' . magazine_palace_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'magazine_palace_infinite_loader_spinner_action', 'magazine_palace_infinite_loader_spinner', 10 );
