<?php
/**
 * Recent Posts Widget
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 */

if ( ! class_exists( 'Magazine_Palace_Recent_Post' ) ) :

     
    class Magazine_palace_Recent_Post extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $tp_widget_recent_post = array(
                'classname'   => 'widget_popular_news',
                'description' => esc_html__( 'Retrive recent posts.', 'magazine-palace' ),
            );
            parent::__construct( 'magazine_palace_Recent_Post', esc_html__( 'TP : Recent Posts', 'magazine-palace' ), $tp_widget_recent_post );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {
            // outputs the content of the widget
            if ( ! isset( $args['widget_id'] ) ) {
                $args['widget_id'] = $this->id;
            }

            $tp_title  = ( ! empty( $instance['title'] ) ) ? ( $instance['title'] ) : '';
            $tp_title  = apply_filters( 'widget_title', $tp_title, $instance, $this->id_base );
            $tp_number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
            $tp_category = isset( $instance['category'] ) ? absint( $instance['category'] ) : '';
            ?> 
            <section id="single-column" class="widget widget_single_column">
                <?php if ( !empty( $tp_title ) ): ?>
                    <div class="widget-header">
                        <h2 class="widget-title"><?php echo esc_html( $tp_title ) ;?></h2>
                    </div><!-- .widget-header -->
                <?php endif ?>
                
            <?php
            $recent_args = array(
                'post_type'         => 'post',
                'posts_per_page'    => absint( $tp_number ),
                'order'             => 'DESC',
                'cat'               => absint( $tp_category ),
                );

            echo '<ul>';
            $wp_query = get_posts( $recent_args );
            	$count = 1;
            foreach ( $wp_query as $post ) :

            $image = !empty( get_the_post_thumbnail_url( $post->ID ) ) ? get_the_post_thumbnail_url( $post->ID, 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
            ?>

	        <li>	        	
	        	<div class="single-column-wrapper">
                    <div class="featured-image">
                        <img src="<?php echo esc_url($image); ?>">
                    </div>
                    <div class="entry-container">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h2>
                        </header>
                        <div class="entry-meta">
                            <?php magazine_palace_posted_on( $post->ID ); ?>
                            <span class="min-read">5 min read</span>
                        </div>
                    </div>
                </div>
	        </li>

            <?php
            endforeach;
            echo '</ul></section>';
        }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {
            $tp_title      = isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Recent Posts', 'magazine-palace' );
            $tp_number     = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
            $tp_category   = isset( $instance['category'] ) ? absint( $instance['category'] ) : '';
           ?>

           <p>
               <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'magazine-palace' ); ?></label>
               <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $tp_title ); ?>" />
           </p>

           <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'magazine-palace' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="7" value="<?php echo absint( $tp_number ); ?>" size="3" />
           </p>

           <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Select the category to show posts:', 'magazine-palace' ); ?></label>
                <select id="<?php echo esc_attr( $this->get_field_id('category') ); ?>" name="<?php echo $this->get_field_name('category'); ?>" class="widefat" style="width:100%;">

                    <?php 
                    $categories = magazine_palace_category_choices();
                    foreach($categories as $category => $value) { ?>
                    <option value="<?php echo absint( $category ); ?>" <?php selected( $tp_category, $category ); ?>><?php echo esc_html( $value ); ?></option>
                    <?php } ?>      
                </select>
            </p>

           <?php
        }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        public function update( $new_instance, $old_instance ) {
            // processes widget options to be saved
            $instance           = $old_instance;
            $instance['title']  = sanitize_text_field( $new_instance['title'] );
            $instance['number'] = (int) $new_instance['number'];
            $instance['category'] = magazine_palace_sanitize_single_category( $new_instance['category'] );
           
            return $instance;
        }
    }
endif;
